
#ifndef _C11_fi515_
#define _C11_fi515_

#ifdef __cplusplus
extern "C" {
#endif

extern EIF_BOOLEAN F539_2686(EIF_REFERENCE);
extern void EIF_Minit515(void);
extern EIF_INTEGER_32 F639_3164(EIF_REFERENCE);

#ifdef __cplusplus
}
#endif

#endif
